==> nextcloud-app-mail-1.3.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_AR.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo",
    "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Favor de usar el modo manual.",
    "Updating account failed: " : "Error al actualizar la cuenta:",
    "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de Correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Add mail account" : "Agregar cuenta de correo",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Select account" : "Seleccione la cuenta",
    "Subject" : "Asunto",
    "Add attachment from Files" : "Agregar adjunto desde Archivos",
    "Sending …" : "Enviando ...",
    "Go back" : "Regresar",
    "Retry" : "Reintentar",
    "Message sent!" : "¡Mensaje enviado!",
    "Send" : "Enviar",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Favorite" : "Favorito",
    "Mark read" : "Marcar como leído",
    "Delete" : "Borrar",
    "to" : "para",
    "cc" : "cc",
    "Reply" : "Responder",
    "Forward" : "Reenviar",
    "Could not load your message" : "No se pudo cargar tu mensaje",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Selecccione la carpeta en la cual almacenar el adjunto",
    "Save all to Files" : "Guardar todos a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger su privacidad. ",
    "New message" : "Mensaje nuevo",
    "Settings" : "Configuraciones ",
    "Add folder" : "Agregar carpeta",
    "Delete account" : "Borrar cuenta",
    "Show all folders" : "Mostrar todos las carpetas",
    "Collapse folders" : "Compactar carpetas",
    "Mark all as read" : "Marcar todos como leídos",
    "Signature" : "Firma",
    "General" : "General",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de correo con estos atajos rápidos.",
    "Compose new message" : "Redactar nuevo mensaje",
    "Newer message" : "Mensaje mas nuevo",
    "Older message" : "Mensaje anterior",
    "Search" : "Buscar",
    "Refresh" : "Recargar",
    "Connect your mail account" : "Conecte su cuenta de correo",
    "All" : "Todos",
    "Archive" : "Archivar",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Correo de Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load the desired message" : "No se pudo cargar el mensaje deseado",
    "Could not load the message" : "No se pudo cargar el mensaje.",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haga click aqui si no es redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "El link lleva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no desea visitar esa página, puede regresar a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.4.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_AR.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo",
    "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Favor de usar el modo manual.",
    "Updating account failed: " : "Error al actualizar la cuenta:",
    "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de Correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Add mail account" : "Agregar cuenta de correo",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Select account" : "Seleccione la cuenta",
    "Subject" : "Asunto",
    "Add attachment from Files" : "Agregar adjunto desde Archivos",
    "Sending …" : "Enviando ...",
    "Go back" : "Regresar",
    "Retry" : "Reintentar",
    "Message sent!" : "¡Mensaje enviado!",
    "Send" : "Enviar",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Favorite" : "Favorito",
    "Mark read" : "Marcar como leído",
    "Select" : "Seleccionar",
    "Delete" : "Borrar",
    "Important" : "Importante",
    "Favorites" : "Favoritos",
    "Other" : "Otro",
    "to" : "para",
    "cc" : "cc",
    "Reply" : "Responder",
    "Forward" : "Reenviar",
    "Could not load your message" : "No se pudo cargar tu mensaje",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Selecccione la carpeta en la cual almacenar el adjunto",
    "Save all to Files" : "Guardar todos a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger su privacidad. ",
    "Show images from this sender" : "Mostrar imagenes de este remitente",
    "New message" : "Mensaje nuevo",
    "Settings" : "Configuraciones ",
    "Quota" : "Cuota",
    "Add folder" : "Agregar carpeta",
    "Remove account" : "Eliminar cuenta",
    "Cancel" : "Cancelar",
    "Show all folders" : "Mostrar todos las carpetas",
    "Collapse folders" : "Compactar carpetas",
    "Mark all as read" : "Marcar todos como leídos",
    "Clear cache" : "Limpiar caché",
    "Signature" : "Firma",
    "General" : "General",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de correo con estos atajos rápidos.",
    "Compose new message" : "Redactar nuevo mensaje",
    "Newer message" : "Mensaje mas nuevo",
    "Older message" : "Mensaje anterior",
    "Search" : "Buscar",
    "Refresh" : "Recargar",
    "Connect your mail account" : "Conecte su cuenta de correo",
    "All" : "Todos",
    "Archive" : "Archivar",
    "Drafts" : "Borradores",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Correo de Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load the desired message" : "No se pudo cargar el mensaje deseado",
    "Could not load the message" : "No se pudo cargar el mensaje.",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haga click aqui si no es redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "El link lleva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no desea visitar esa página, puede regresar a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=2; plural=(n != 1);");
